package com.ruoyi.dz.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.dz.mapper.DzSubjectMapper;
import com.ruoyi.dz.domain.DzSubject;
import com.ruoyi.dz.service.IDzSubjectService;

/**
 * 科目Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-09-27
 */
@Service
public class DzSubjectServiceImpl implements IDzSubjectService 
{
    @Autowired
    private DzSubjectMapper dzSubjectMapper;

    public List<DzSubject> selectDzSubjectBySubjectIds(Long[] subjectIds) {
        return dzSubjectMapper.selectDzSubjectBySubjectIds(subjectIds);
    }
    /**
     * 查询科目
     * 
     * @param subjectId 科目主键
     * @return 科目
     */
    @Override
    public DzSubject selectDzSubjectBySubjectId(Long subjectId)
    {
        return dzSubjectMapper.selectDzSubjectBySubjectId(subjectId);
    }

    /**
     * 查询科目列表
     * 
     * @param dzSubject 科目
     * @return 科目
     */
    @Override
    public List<DzSubject> selectDzSubjectList(DzSubject dzSubject)
    {
        return dzSubjectMapper.selectDzSubjectList(dzSubject);
    }

    /**
     * 新增科目
     * 
     * @param dzSubject 科目
     * @return 结果
     */
    @Override
    public int insertDzSubject(DzSubject dzSubject)
    {
        return dzSubjectMapper.insertDzSubject(dzSubject);
    }

    /**
     * 修改科目
     * 
     * @param dzSubject 科目
     * @return 结果
     */
    @Override
    public int updateDzSubject(DzSubject dzSubject)
    {
        return dzSubjectMapper.updateDzSubject(dzSubject);
    }

    /**
     * 批量删除科目
     * 
     * @param subjectIds 需要删除的科目主键
     * @return 结果
     */
    @Override
    public int deleteDzSubjectBySubjectIds(Long[] subjectIds)
    {
        return dzSubjectMapper.deleteDzSubjectBySubjectIds(subjectIds);
    }

    /**
     * 删除科目信息
     * 
     * @param subjectId 科目主键
     * @return 结果
     */
    @Override
    public int deleteDzSubjectBySubjectId(Long subjectId)
    {
        return dzSubjectMapper.deleteDzSubjectBySubjectId(subjectId);
    }
}
