package com.ruoyi.web.controller.dz;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.AjaxResult2;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dz.domain.DzSubject;
import com.ruoyi.dz.service.IDzSubjectService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 科目Controller
 * 
 * @author ruoyi
 * @date 2025-09-27
 */
@RestController
@RequestMapping("/dz/subject")
@Api(tags = "后台-科目")
public class DzSubjectController extends BaseController
{
    @Autowired
    private IDzSubjectService dzSubjectService;

    /**
     * 查询科目列表
     */
    @PreAuthorize("@ss.hasPermi('dz:subject:list')")
    @GetMapping("/list")
    public TableDataInfo list(DzSubject dzSubject)
    {
        startPage();
        List<DzSubject> list = dzSubjectService.selectDzSubjectList(dzSubject);
        return getDataTable(list);
    }

    @GetMapping("/listAll")
    @ApiOperation("知识点列表")
    public AjaxResult2<List<DzSubject>> listAll(DzSubject dzSubject)
    {
        List<DzSubject> list = dzSubjectService.selectDzSubjectList(dzSubject);
        return AjaxResult2.success(list);
    }

    /**
     * 导出科目列表
     */
    @PreAuthorize("@ss.hasPermi('dz:subject:export')")
    @Log(title = "科目", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DzSubject dzSubject)
    {
        List<DzSubject> list = dzSubjectService.selectDzSubjectList(dzSubject);
        ExcelUtil<DzSubject> util = new ExcelUtil<DzSubject>(DzSubject.class);
        util.exportExcel(response, list, "科目数据");
    }

    /**
     * 获取科目详细信息
     */
    @PreAuthorize("@ss.hasPermi('dz:subject:query')")
    @GetMapping(value = "/{subjectId}")
    public AjaxResult getInfo(@PathVariable("subjectId") Long subjectId)
    {
        return success(dzSubjectService.selectDzSubjectBySubjectId(subjectId));
    }

    /**
     * 新增科目
     */
    @PreAuthorize("@ss.hasPermi('dz:subject:add')")
    @Log(title = "科目", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DzSubject dzSubject)
    {
        return toAjax(dzSubjectService.insertDzSubject(dzSubject));
    }

    /**
     * 修改科目
     */
    @PreAuthorize("@ss.hasPermi('dz:subject:edit')")
    @Log(title = "科目", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DzSubject dzSubject)
    {
        return toAjax(dzSubjectService.updateDzSubject(dzSubject));
    }

    /**
     * 删除科目
     */
    @PreAuthorize("@ss.hasPermi('dz:subject:remove')")
    @Log(title = "科目", businessType = BusinessType.DELETE)
	@DeleteMapping("/{subjectIds}")
    public AjaxResult remove(@PathVariable Long[] subjectIds)
    {
        return toAjax(dzSubjectService.deleteDzSubjectBySubjectIds(subjectIds));
    }
}
